@@ -8,14 +8,23 @@ from django.db import models
 from django.db.models import Avg, Min, Max, Count, Sum
 from django.db.models.signals import post_save
 from report_builder.unique_slugify import unique_slugify
-from report_builder.utils import get_model_from_path_string
+from report_utils.model_introspection import get_model_from_path_string
 from dateutil import parser
 
 AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
+
 class Report(models.Model):
     """ A saved report with queryset and descriptive fields
     """
+    def _get_model_manager(self):
+        """ Get  manager from settings else use objects
+        """
+        model_manager = 'objects'
+        if getattr(settings, 'REPORT_BUILDER_MODEL_MANAGER', False):
+            model_manager = settings.REPORT_BUILDER_MODEL_MANAGER
+        return model_manager
+
     def _get_allowed_models():
         models = ContentType.objects.all()
         if getattr(settings, 'REPORT_BUILDER_INCLUDE', False):
@@ -33,17 +42,17 @@ class Report(models.Model):
     user_created = models.ForeignKey(AUTH_USER_MODEL, editable=False, blank=True, null=True)
     user_modified = models.ForeignKey(AUTH_USER_MODEL, editable=False, blank=True, null=True, related_name="report_modified_set")
     distinct = models.BooleanField(default=False)
+    report_file = models.FileField(upload_to="report_files", blank=True)
+    report_file_creation = models.DateTimeField(blank=True, null=True)
     starred = models.ManyToManyField(AUTH_USER_MODEL, blank=True,
                                      help_text="These users have starred this report for easy reference.",
                                      related_name="report_starred_set")
-    
-    
+
     def save(self, *args, **kwargs):
         if not self.id:
             unique_slugify(self, self.name)
         super(Report, self).save(*args, **kwargs)
 
-
     def add_aggregates(self, queryset):
         for display_field in self.displayfield_set.filter(aggregate__isnull=False):
             if display_field.aggregate == "Avg":
@@ -57,13 +66,19 @@ class Report(models.Model):
             elif display_field.aggregate == "Sum":
                 queryset = queryset.annotate(Sum(display_field.path + display_field.field))
         return queryset
-
     
     def get_query(self):
         report = self
         model_class = report.root_model.model_class()
         message= ""
-        objects = model_class.objects.all()
+
+        # Check for report_builder_model_manger property on the model
+        if getattr(model_class, 'report_builder_model_manager', False):
+            objects = getattr(model_class, 'report_builder_model_manager').all()
+        else:
+            # Get global model manager
+            manager = report._get_model_manager()
+            objects = getattr(model_class, manager).all()
 
         # Filters
         # NOTE: group all the filters together into one in order to avoid 
@@ -148,10 +163,16 @@ class Report(models.Model):
     edit.allow_tags = True
     
     def download_xlsx(self):
-        return mark_safe('<a href="{0}"><img style="width: 26px; margin: -6px" src="{1}report_builder/img/download.svg"/></a>'.format(
-            reverse('report_builder.views.download_xlsx', args=[self.id]),
-            getattr(settings, 'STATIC_URL', '/static/'),
-        ))
+        if getattr(settings, 'REPORT_BUILDER_ASYNC_REPORT', False):
+            return mark_safe('<a href="#" onclick="get_async_report({0})"><img style="width: 26px; margin: -6px" src="{1}report_builder/img/download.svg"/></a>'.format(
+                self.id,
+                getattr(settings, 'STATIC_URL', '/static/'),
+            ))
+        else:
+            return mark_safe('<a href="{0}"><img style="width: 26px; margin: -6px" src="{1}report_builder/img/download.svg"/></a>'.format(
+                reverse('report_download_xlsx', args=[self.id]),
+                getattr(settings, 'STATIC_URL', '/static/'),
+            ))
     download_xlsx.short_description = "Download"
     download_xlsx.allow_tags = True
     
@@ -220,7 +241,8 @@ class DisplayField(models.Model):
         except:
             model_field = None
         if model_field and model_field.choices:
-            return model_field.choices
+            # See https://github.com/burke-software/django-report-builder/pull/93
+            return ((model_field.get_prep_value(key), val) for key, val in model_field.choices)
 
     @property
     def choices_dict(self):
